# -*- coding: utf-8 -*-
# #############################################################################
# Copyright (C) 2022 manatlan manatlan[at]gmail(dot)com
#
# MIT licence
#
# https://github.com/manatlan/htbulma
# #############################################################################
from .. import TagBulma,Button,Box
from htag import Tag

class MBox(TagBulma):
    tag="div"

    def __init__(self, parent):
        """ auto attach on 'parent' """
        super().__init__()
        self["info"]="mbox"
        parent.add( self )

    def show(self, content, canClose=True):
        self.clear()
        o = Tag.div(_class = "modal is-active")

        jsclose= self.bind.close()

        if canClose:
            o <= Tag.div(_class="modal-background", _onclick=jsclose)
            o <= Tag.div(
                    _class="modal-close is-large",
                    _aria_label="close",
                    _onclick=jsclose,
                )
        else:
            o <= Tag.div(_class="modal-background")

        o <= Tag.div( Box(content), _class="modal-content")
        self.add( o )

    def close(self):
        self.clear()



if __name__=="__main__":


    obj=Tag( )
    MBox(obj).show("YO")

    from .. import _test
    _test( obj )



# -*- coding: utf-8 -*-
# #############################################################################
# Copyright (C) 2022 manatlan manatlan[at]gmail(dot)com
#
# MIT licence
#
# https://github.com/manatlan/htbulma
# #############################################################################
from . import TagBulma,TabsHeader,Box

class Tabs(TagBulma): # New version (htag optimized, but can bo better with built lately)

    def __init__(self,**a):
        super().__init__(**a)
        self.__tabs={}
        self.__selected = None

    def addTab(self,name,content):
        self.__tabs[name] = content
        if self.__selected is None:
            self.__selected=name
        self._render()

    def _render(self):
        self.clear()

        ll=[]
        for k,v in self.__tabs.items():
            ll.append(k)

        if self.__selected:
            if len(ll)>0:
                self <= TabsHeader(self.__selected, ll, onchange=self._setselected )
                self <= Box(self.__tabs[ self.__selected ])

    @property
    def selected(self):
        return self.__selected

    @selected.setter
    def selected(self, v):
        self._setselected(v)

    def _setselected(self,v):
        assert v in self.__tabs.keys()
        self.__selected = v
        self._render()

if __name__=="__main__":

    obj=Tabs()
    obj.addTab("P1", "I'm the page1")
    obj.addTab("P2", "Currently, I am the page2 !")

    from . import _test
    _test( obj )




# -*- coding: utf-8 -*-
# #############################################################################
# Copyright (C) 2022 manatlan manatlan[at]gmail(dot)com
#
# MIT licence
#
# https://github.com/manatlan/htbulma
# #############################################################################
from . import TagBulma, A
from htag import Tag

class _Selector(TagBulma): # not HTAG OPTIMIZED, and others too!
    def __init__(self, value, choices: list, disabled=False, onchange=None,**a):
        super().__init__(**a)
        assert value in choices
        self.value = value
        self.choices = choices
        self.disabled = disabled
        self.onchange = onchange
        self.update()

    def _selectVal(self, idx):
        self.value = self.choices[int(idx)]
        if self.onchange:
            self.onchange(self.value)
        self.update()


class TabsHeader(_Selector):  # TODO: implement disabled
    tag="div"

    def update(self):
        self.clear()
        self.classEnsure("tabs is-centered")

        u = Tag.ul()
        for idx, i in enumerate(self.choices):
            isActive = "is-active" if self.value == i else None
            u <= Tag.li(A(i, _onclick=self.bind._selectVal(idx)), _class=isActive)
        self <= u



class RadioButtons(_Selector):
    tag="div"

    def update(self):
        self.clear()
        self.classEnsure("control")

        for idx, i in enumerate(self.choices):
            self <= Tag.label(
                        [
                            Tag.input(
                                _type="radio",
                                _class="radio",  # override
                                _name="r%s" % id(self),
                                _onclick=self.bind._selectVal(idx),
                                _checked=(self.value == i),
                                _disabled=bool(self.disabled),
                            ),
                            i
                        ],
                        _class="radio",
                    )

class SelectButtons(_Selector):  # TODO: add disabled ?
    tag="div"

    def update(self):
        self.clear()
        self.classEnsure("tabs is-toggle")
        u = Tag.ul()
        for idx, i in enumerate(self.choices):
            isActive = "is-active" if self.value == i else None
            u<=Tag.li(A(i, _onclick=self.bind._selectVal(idx)), _class=isActive)
        self <= u


class Select(_Selector):
    tag="div"

    def update(self):
        self.clear()
        self.classEnsure("select")
        s = Tag.select(
            _onchange=self.bind._selectVal(b"this.value"),
            _style="width:100%",
            _disabled=bool(self.disabled),
        )
        for idx, i in enumerate(self.choices):
            s <= Tag.option(i, _value=idx, _selected=(self.value == i))

        self <= s


if __name__=="__main__":

    s = 2
    obj=Tag.div( )
    obj<=TabsHeader(s, [1, 2, 3] )
    obj<=RadioButtons(s, [1, 2, 3]),
    obj<=SelectButtons(s, [1, 2, 3]),
    obj<=Select(s, [1, 2, 3] ),

    from . import _test
    _test( obj )



# -*- coding: utf-8 -*-
# #############################################################################
# Copyright (C) 2022 manatlan manatlan[at]gmail(dot)com
#
# MIT licence
#
# https://github.com/manatlan/htbulma
# #############################################################################

from . import TagBulma
from htag import Tag


class InputText(TagBulma): # not HTAG OPTIMIZED
    tag="input"

    def __init__(self, value, type="text", disabled=False, onchange=None,**a):
        super().__init__(**a)
        self.classEnsure("input")
        self["type"]=type
        self["onchange"]=self.bind.changeValue(b"this.value")

        self.value = value
        self.disabled = disabled
        self.onchange = onchange
        self.update()

    def update(self):
        self["disabled"]=self.disabled
        self["value"]= self.value

    def changeValue(self, value):
        self.value = value
        if self.onchange:
            self.onchange(self.value)
        self.update()


class TextArea(TagBulma):    # not HTAG OPTIMIZED
    tag="textarea"

    def __init__(self, value, disabled=False, onchange=None,**a):
        super().__init__(**a)
        self.classEnsure("input")
        self["onchange"]=self.bind.changeValue(b"this.value")

        self.value = value
        self.disabled = disabled
        self.onchange = onchange
        self.update()

    def update(self):
        self.clear()
        self["disabled"]=self.disabled
        self<=self.value

    def changeValue(self, value):
        self.value = value
        if self.onchange:
            self.onchange(self.value)
        self.update()

class Checkbox(TagBulma):
    tag="div"

    def __init__(self, value: bool, title: str, disabled=False, onchange=None,**a):
        super().__init__(**a)
        self.value = value
        self.title = title
        self.disabled = disabled
        self.onchange = onchange
        self.update()

    def update(self):
        self.clear()
        self.add(
            Tag.label(
                [
                    Tag.input(
                        _checked=self.value,
                        _type="checkbox",
                        _class="checkbox",
                        _onclick=self.bind.switch(),
                        _disabled=self.disabled,
                    ),
                    self.title,
                ],
                _class="checkbox",
            )
        )

    def switch(self):
        self.value = not self.value
        if self.onchange:
            self.onchange(self.value)
        self.update()



class Slider(TagBulma):
    tag="input"

    def __init__(self, value, min=None, max=None, step=None, onchange=None,**a):
        TagBulma.__init__(self,**a)
        self["type"]="range"
        self.classEnsure("slider is-fullwidth")
        self["value"]=value
        self["min"]=min
        self["max"]=max
        self["step"]=step
        self["oninput"] = self.bind.changeValue(b"this.value")
        self.onchange = onchange

    def changeValue(self,v):
        self["value"] = v
        if self.onchange:
            self.onchange(v)

if __name__=="__main__":
    obj=Tag.div( )
    obj <= Input()
    obj <= InputText("hello")
    obj <= TextArea("hello")
    obj <= Checkbox(True,"Yolo")
    obj <= Slider(42,0,100)

    from . import _test
    _test( obj )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['htbulma', 'htbulma.services']

package_data = \
{'': ['*']}

install_requires = \
['htag>=0.0,<0.1']

setup_kwargs = {
    'name': 'htbulma',
    'version': '0.0.2',
    'description': 'GUI toolkit for creating beautiful applications for mobile, web, and desktop from a single python3 codebase',
    'long_description': '## htbulma = "HTag bulma"\n\nExemple of gui toolkit using [htag](https://github.com/manatlan/htag).\n\n[available on pypi](https://pypi.org/project/htbulma/)\n\n[See an example](test.py)\n',
    'author': 'manatlan',
    'author_email': 'manatlan@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/manatlan/htbulma',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
